# Project Dependencies

| Package | Version Spec | Description | Homepage |
|---------|--------------|-------------|----------|
| `pydantic` | `>=2.4, <3.0` | Data validation using Python type hints | [https://pypi.org/project/pydantic/](https://pypi.org/project/pydantic/) |
| `colorama` | `>=0.4, <1.0` | Cross-platform colored terminal text. | [https://pypi.org/project/colorama/](https://pypi.org/project/colorama/) |
| `click` | `>=8.1, <9.0` | Composable command line interface toolkit | [https://pypi.org/project/click/](https://pypi.org/project/click/) |
| `httpx` | `>=0, <1` | The next generation HTTP client. | [https://pypi.org/project/httpx/](https://pypi.org/project/httpx/) |
| `pandas` | `>=2, <3` | Powerful data structures for data analysis, time series, and statistics | [https://pandas.pydata.org](https://pandas.pydata.org) |
| `nest-asyncio2` | `>=1.6, <2.0` | Patch asyncio to allow nested event loops | [https://github.com/Chaoses-Ib/nest-asyncio2](https://github.com/Chaoses-Ib/nest-asyncio2) |
| `rich` | `>=13.6, <14.0` | Render rich text, tables, progress bars, syntax highlighting, markdown and more to the terminal | [https://pypi.org/project/rich/](https://pypi.org/project/rich/) |
| `pytket` | `>=2.3.1, <3.0` | Quantum computing toolkit and interface to the TKET compiler | [https://pypi.org/project/pytket/](https://pypi.org/project/pytket/) |
| `websockets` | `>11, <16` | An implementation of the WebSocket Protocol (RFC 6455 & 7692) | [https://pypi.org/project/websockets/](https://pypi.org/project/websockets/) |
| `pydantic-settings` | `>=2, <3.0` | Settings management using Pydantic | [https://pypi.org/project/pydantic-settings/](https://pypi.org/project/pydantic-settings/) |
| `quantinuum-schemas` | `>=7.6.0, <8.0` | Shared data models for Quantinuum. | [https://github.com/CQCL/quantinuum-schemas](https://github.com/CQCL/quantinuum-schemas) |
| `hugr` | `>=0.14.0, <1.0.0` | Quantinuum's common representation for quantum programs | [https://github.com/quantinuum/hugr/tree/main/hugr-py](https://github.com/quantinuum/hugr/tree/main/hugr-py) |
| `pyjwt` | `>=2.10.1,<3.0.0` | JSON Web Token implementation in Python | [https://pypi.org/project/PyJWT/](https://pypi.org/project/PyJWT/) |
